from django import forms
from edc_crf.modelform_mixins import CrfModelFormMixin
from edc_form_validators import FormValidator


class IcecapaFormValidator(FormValidator):
    pass


class IcecapaForm(CrfModelFormMixin, forms.ModelForm):
    form_validator_cls = IcecapaFormValidator



# Generated by Django 4.2.1 on 2023-05-21 11:19

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_qol", "0004_icecapa_historicalicecapa"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalicecapa",
            name="enjoyment",
            field=models.CharField(
                choices=[
                    ("4", "I can have <B>a lot</B> of enjoyment and pleasure"),
                    ("3", "I can have <B>quite a lot</B> of enjoyment and pleasure"),
                    ("2", "I can have <B>a little</B> enjoyment and pleasure"),
                    ("1", "I <B>cannot</B> have <B>any</B> enjoyment and pleasure"),
                ],
                max_length=5,
                verbose_name="Enjoyment and pleasure",
            ),
        ),
        migrations.AlterField(
            model_name="icecapa",
            name="enjoyment",
            field=models.CharField(
                choices=[
                    ("4", "I can have <B>a lot</B> of enjoyment and pleasure"),
                    ("3", "I can have <B>quite a lot</B> of enjoyment and pleasure"),
                    ("2", "I can have <B>a little</B> enjoyment and pleasure"),
                    ("1", "I <B>cannot</B> have <B>any</B> enjoyment and pleasure"),
                ],
                max_length=5,
                verbose_name="Enjoyment and pleasure",
            ),
        ),
    ]



from .eq5d3l_model_admin_mixin import (
    Eq5d3lModelAdminMixin,
    eq5d3l_fieldsets,
    eq5d3l_radio_fields,
)
from .icecapa_model_admin_mixin import (
    IcecapaModelAdminMixin,
    icecapa_fieldsets,
    icecapa_radio_fields,
)



# Generated by Django 4.1.7 on 2023-04-25 15:46

import uuid

import _socket
import django.db.models.deletion
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django_audit_fields.models.audit_model_mixin
import django_revision.revision_field
import edc_sites.models
import edc_utils.date
import simple_history.models
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("sites", "0002_alter_domain_unique"),
        ("edc_qol", "0003_auto_20220704_1841"),
    ]

    operations = [
        migrations.CreateModel(
            name="Icecapa",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("subject_identifier", models.CharField(max_length=50, unique=True)),
                (
                    "stability",
                    models.CharField(
                        choices=[
                            (
                                "4",
                                "I am able to feel settled and secure in <B>all</B> areas of my life",
                            ),
                            (
                                "3",
                                "I am able to feel settled and secure in <B>many</B> areas of my life",
                            ),
                            (
                                "2",
                                "I am able to feel settled and secure in a <B>few</B> areas of my life",
                            ),
                            (
                                "1",
                                "I am <B>unable</B> to feel settled and secure in <B>any</B> areas of my life",
                            ),
                        ],
                        max_length=5,
                        verbose_name="Feeling settled and secure",
                    ),
                ),
                (
                    "attachment",
                    models.CharField(
                        choices=[
                            ("4", "I can have <B>a lot</B> of love, friendship and support"),
                            (
                                "3",
                                "I can have <B>quite a lot</B> of love, friendship and support",
                            ),
                            ("2", "I can have <B>a little</B> love, friendship and support"),
                            (
                                "1",
                                "I <B>cannot</B> have <B>any</B> love, friendship and support",
                            ),
                        ],
                        max_length=5,
                        verbose_name="Love, friendship and support",
                    ),
                ),
                (
                    "autonomy",
                    models.CharField(
                        choices=[
                            ("4", "I am able to be <B>completely</B> independent"),
                            ("3", "I am able to be independent in <B>many</B> things"),
                            ("2", "I am able to be independent in <B>a few</B> things"),
                            ("1", "I am <B>unable</B> to be at all independent"),
                        ],
                        max_length=5,
                        verbose_name="Being independent",
                    ),
                ),
                (
                    "achievement",
                    models.CharField(
                        choices=[
                            (
                                "4",
                                "I can achieve and progress in <B>all</B> aspects of my life",
                            ),
                            (
                                "3",
                                "I can achieve and progress in <B>many</B> aspects of my life",
                            ),
                            (
                                "2",
                                "I can achieve and progress in <B>a few</B> aspects of my life",
                            ),
                            (
                                "1",
                                "I <B>cannot</B> achieve and progress in <B>any</B> aspects of my life",
                            ),
                        ],
                        max_length=5,
                        verbose_name="Achievement and progress",
                    ),
                ),
                (
                    "enjoyment",
                    models.CharField(
                        choices=[
                            ("4", "I can have a lot of enjoyment and pleasure"),
                            ("3", "I can have quite a lot of enjoyment and pleasure"),
                            ("2", "I can have a little enjoyment and pleasure"),
                            ("1", "I cannot have any enjoyment and pleasure"),
                        ],
                        max_length=5,
                        verbose_name="Enjoyment and pleasure",
                    ),
                ),
                ("report_datetime", models.DateTimeField(default=edc_utils.date.get_utcnow)),
                (
                    "site",
                    models.ForeignKey(
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
            ],
            options={
                "verbose_name": "Overall quality of life (ICECAP-A V2)",
                "verbose_name_plural": "Overall quality of life (ICECAP-A V2)",
                "ordering": ("-modified", "-created"),
                "get_latest_by": "modified",
                "abstract": False,
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
            },
            managers=[
                ("on_site", edc_sites.models.CurrentSiteManager()),
            ],
        ),
        migrations.CreateModel(
            name="HistoricalIcecapa",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        db_index=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                    ),
                ),
                ("subject_identifier", models.CharField(db_index=True, max_length=50)),
                (
                    "stability",
                    models.CharField(
                        choices=[
                            (
                                "4",
                                "I am able to feel settled and secure in <B>all</B> areas of my life",
                            ),
                            (
                                "3",
                                "I am able to feel settled and secure in <B>many</B> areas of my life",
                            ),
                            (
                                "2",
                                "I am able to feel settled and secure in a <B>few</B> areas of my life",
                            ),
                            (
                                "1",
                                "I am <B>unable</B> to feel settled and secure in <B>any</B> areas of my life",
                            ),
                        ],
                        max_length=5,
                        verbose_name="Feeling settled and secure",
                    ),
                ),
                (
                    "attachment",
                    models.CharField(
                        choices=[
                            ("4", "I can have <B>a lot</B> of love, friendship and support"),
                            (
                                "3",
                                "I can have <B>quite a lot</B> of love, friendship and support",
                            ),
                            ("2", "I can have <B>a little</B> love, friendship and support"),
                            (
                                "1",
                                "I <B>cannot</B> have <B>any</B> love, friendship and support",
                            ),
                        ],
                        max_length=5,
                        verbose_name="Love, friendship and support",
                    ),
                ),
                (
                    "autonomy",
                    models.CharField(
                        choices=[
                            ("4", "I am able to be <B>completely</B> independent"),
                            ("3", "I am able to be independent in <B>many</B> things"),
                            ("2", "I am able to be independent in <B>a few</B> things"),
                            ("1", "I am <B>unable</B> to be at all independent"),
                        ],
                        max_length=5,
                        verbose_name="Being independent",
                    ),
                ),
                (
                    "achievement",
                    models.CharField(
                        choices=[
                            (
                                "4",
                                "I can achieve and progress in <B>all</B> aspects of my life",
                            ),
                            (
                                "3",
                                "I can achieve and progress in <B>many</B> aspects of my life",
                            ),
                            (
                                "2",
                                "I can achieve and progress in <B>a few</B> aspects of my life",
                            ),
                            (
                                "1",
                                "I <B>cannot</B> achieve and progress in <B>any</B> aspects of my life",
                            ),
                        ],
                        max_length=5,
                        verbose_name="Achievement and progress",
                    ),
                ),
                (
                    "enjoyment",
                    models.CharField(
                        choices=[
                            ("4", "I can have a lot of enjoyment and pleasure"),
                            ("3", "I can have quite a lot of enjoyment and pleasure"),
                            ("2", "I can have a little enjoyment and pleasure"),
                            ("1", "I cannot have any enjoyment and pleasure"),
                        ],
                        max_length=5,
                        verbose_name="Enjoyment and pleasure",
                    ),
                ),
                ("report_datetime", models.DateTimeField(default=edc_utils.date.get_utcnow)),
                (
                    "history_id",
                    models.UUIDField(
                        default=uuid.uuid4, editable=False, primary_key=True, serialize=False
                    ),
                ),
                ("history_date", models.DateTimeField(db_index=True)),
                ("history_change_reason", models.CharField(max_length=100, null=True)),
                (
                    "history_type",
                    models.CharField(
                        choices=[("+", "Created"), ("~", "Changed"), ("-", "Deleted")],
                        max_length=1,
                    ),
                ),
                (
                    "history_user",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
            ],
            options={
                "verbose_name": "historical Overall quality of life (ICECAP-A V2)",
                "verbose_name_plural": "historical Overall quality of life (ICECAP-A V2)",
                "ordering": ("-history_date", "-history_id"),
                "get_latest_by": ("history_date", "history_id"),
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
    ]



from django.db import models
from django.utils.translation import gettext_lazy as _

from edc_qol.choices import (
    ICECAP_ACHIEVMENT,
    ICECAP_ATTACHMENT,
    ICECAP_AUTONOMY,
    ICECAP_ENJOYMENT,
    ICECAP_STABILITY,
)


class IcecapaModelMixin(models.Model):
    """
    Al-Janabi H, Flynn TN, Coast J. Development of a self-report
    measure of capability wellbeing for adults: the ICECAP-A.
    Quality of Life Research. 2012;21:167–176
    """

    stability = models.CharField(
        verbose_name=_("Feeling settled and secure"),
        choices=ICECAP_STABILITY,
        max_length=5,
    )

    attachment = models.CharField(
        verbose_name=_("Love, friendship and support"),
        choices=ICECAP_ATTACHMENT,
        max_length=5,
    )

    autonomy = models.CharField(
        verbose_name=_("Being independent"),
        choices=ICECAP_AUTONOMY,
        max_length=5,
    )

    achievement = models.CharField(
        verbose_name=_("Achievement and progress"),
        choices=ICECAP_ACHIEVMENT,
        max_length=5,
    )

    enjoyment = models.CharField(
        verbose_name=_("Enjoyment and pleasure"),
        choices=ICECAP_ENJOYMENT,
        max_length=5,
    )

    class Meta:
        verbose_name = _("Overall quality of life (ICECAP-A V2)")
        verbose_name_plural = _("Overall quality of life (ICECAP-A V2)")
        abstract = True



from django.contrib import admin
from edc_model_admin.dashboard import ModelAdminSubjectDashboardMixin
from edc_model_admin.history import SimpleHistoryAdmin

from ..admin_site import edc_qol_admin
from ..forms import Eq5d3lForm
from ..modeladmin_mixins import Eq5d3lModelAdminMixin
from ..models import Eq5d3l


@admin.register(Eq5d3l, site=edc_qol_admin)
class Eq5d3lAdmin(Eq5d3lModelAdminMixin, ModelAdminSubjectDashboardMixin, SimpleHistoryAdmin):
    form = Eq5d3lForm



from edc_auth.site_auths import site_auths

from .auth_objects import QOL, QOL_SUPER, QOL_VIEW, edc_qol_codenames

site_auths.add_group(*edc_qol_codenames, name=QOL_VIEW, view_only=True)
site_auths.add_group(*edc_qol_codenames, name=QOL, no_delete=True)
site_auths.add_group(*edc_qol_codenames, name=QOL_SUPER)



from django import forms
from edc_crf.crf_form_validator import CrfFormValidator
from edc_crf.modelform_mixins import CrfModelFormMixin
from edc_model.widgets import SliderWidget

from ..models import Eq5d3l


class Eq5d3lFormValidator(CrfFormValidator):
    def clean(self) -> None:
        self.confirm_scores_match()

    def confirm_scores_match(self):
        confirmed = self.cleaned_data.get("health_today_score_confirmed")
        if confirmed is not None:
            if int(self.cleaned_data.get("health_today_score_slider", "0")) != confirmed:
                raise forms.ValidationError(
                    {"health_today_score_confirmed": "Does not match visual scale above."}
                )


class Eq5d3lForm(CrfModelFormMixin, forms.ModelForm):
    form_validator_cls = Eq5d3lFormValidator

    health_today_score_slider = forms.CharField(
        label="Health TODAY scale", widget=SliderWidget(attrs={"min": 0, "max": 100})
    )

    class Meta:
        model = Eq5d3l
        fields = "__all__"



from django.db import models
from edc_identifier.model_mixins import UniqueSubjectIdentifierFieldMixin
from edc_model.models import BaseUuidModel, HistoricalRecords
from edc_sites.managers import CurrentSiteManager
from edc_sites.model_mixins import SiteModelMixin
from edc_utils import get_utcnow

from ..model_mixins import Eq5d3lModelMixin


class Eq5d3l(
    UniqueSubjectIdentifierFieldMixin,
    Eq5d3lModelMixin,
    SiteModelMixin,
    BaseUuidModel,
):
    report_datetime = models.DateTimeField(default=get_utcnow)

    objects = models.Manager()
    on_site = CurrentSiteManager()
    history = HistoricalRecords()

    class Meta(Eq5d3lModelMixin.Meta, BaseUuidModel.Meta):
        pass



from django.db import models
from django.utils.html import format_html
from django.utils.translation import gettext_lazy as _
from edc_constants.choices import YES_NO

from ..choices import (
    DESCRIBE_HEALTH_CHOICES,
    FEELING_DURATION_CHOICES,
    HEALTH_LIMITED_CHOICES,
    INTERFERENCE_DURATION_CHOICES,
    WORK_PAIN_INTERFERENCE_CHOICES,
)


class Sf12ModelMixin(models.Model):
    general_health = models.CharField(
        verbose_name=_("In general, would you say your health is:"),
        max_length=15,
        choices=DESCRIBE_HEALTH_CHOICES,
    )

    moderate_activities_now_limited = models.CharField(
        verbose_name=format_html(
            _(
                "<u>Moderate activities</u> such as moving a table, "
                "pushing a vacuum cleaner, bowling, or playing golf:"
            )
        ),
        max_length=20,
        choices=HEALTH_LIMITED_CHOICES,
    )

    climbing_stairs_now_limited = models.CharField(
        verbose_name=format_html(_("Climbing <u>several</u> flights of stairs:")),
        max_length=20,
        choices=HEALTH_LIMITED_CHOICES,
    )

    accomplished_less_physical_health = models.CharField(
        verbose_name=format_html(_("<u>Accomplished less</u> than you would like:")),
        max_length=15,
        choices=YES_NO,
    )

    work_limited_physical_health = models.CharField(
        verbose_name=format_html(
            _("Were limited in the <u>kind</u> of work or other activities:")
        ),
        max_length=15,
        choices=YES_NO,
    )

    accomplished_less_emotional = models.CharField(
        verbose_name=format_html(_("<u>Accomplished less</u> than you would like:")),
        max_length=15,
        choices=YES_NO,
    )

    work_less_carefully_emotional = models.CharField(
        verbose_name=format_html(
            _("Did work or activities <u>less carefully than usual</u>:")
        ),
        max_length=15,
        choices=YES_NO,
    )

    pain_interfere_work = models.CharField(
        verbose_name=format_html(
            _(
                "During the <u>past 4 weeks</u>, how much <u>did pain interfere</u> "
                "with your normal work (including work outside the home and housework)?"
            )
        ),
        max_length=15,
        choices=WORK_PAIN_INTERFERENCE_CHOICES,
    )

    felt_calm_peaceful = models.CharField(
        verbose_name=_("Have you felt calm & peaceful?"),
        max_length=25,
        choices=FEELING_DURATION_CHOICES,
    )

    felt_lot_energy = models.CharField(
        verbose_name=_("Did you have a lot of energy?"),
        max_length=25,
        choices=FEELING_DURATION_CHOICES,
    )

    felt_down = models.CharField(
        verbose_name=_("Have you felt down-hearted and blue?"),
        max_length=25,
        choices=FEELING_DURATION_CHOICES,
    )

    social_activities_interfered = models.CharField(
        verbose_name=format_html(
            _(
                "During the <u>past 4 weeks</u>, how much of the time has your physical "
                "health or emotional problems interfered with your social "
                "activities (like visiting friends, relatives, etc.)?"
            )
        ),
        max_length=25,
        choices=INTERFERENCE_DURATION_CHOICES,
    )

    class Meta:
        abstract = True
        verbose_name = _("SF-12 Health Survey")
        verbose_name_plural = _("SF-12 Health Survey")



# Generated by Django 4.2.7 on 2023-12-04 22:19

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_qol", "0009_alter_historicalsf12_felt_calm_peaceful_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="eq5d3l",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "EuroQol EQ-5D-3L Instrument",
                "verbose_name_plural": "EuroQol EQ-5D-3L Instrument",
            },
        ),
        migrations.AlterModelOptions(
            name="icecapa",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Overall quality of life (ICECAP-A V2)",
                "verbose_name_plural": "Overall quality of life (ICECAP-A V2)",
            },
        ),
        migrations.AlterModelOptions(
            name="sf12",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "SF-12 Health Survey",
                "verbose_name_plural": "SF-12 Health Survey",
            },
        ),
        migrations.AddField(
            model_name="eq5d3l",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="eq5d3l",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicaleq5d3l",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicaleq5d3l",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalicecapa",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalicecapa",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalsf12",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalsf12",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="icecapa",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="icecapa",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="sf12",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="sf12",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddIndex(
            model_name="eq5d3l",
            index=models.Index(
                fields=["modified", "created"], name="edc_qol_eq5_modifie_5b9704_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="eq5d3l",
            index=models.Index(
                fields=["user_modified", "user_created"],
                name="edc_qol_eq5_user_mo_752b10_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="icecapa",
            index=models.Index(
                fields=["modified", "created"], name="edc_qol_ice_modifie_a1ffe2_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="icecapa",
            index=models.Index(
                fields=["user_modified", "user_created"],
                name="edc_qol_ice_user_mo_1508fd_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="sf12",
            index=models.Index(
                fields=["modified", "created"], name="edc_qol_sf1_modifie_f01725_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="sf12",
            index=models.Index(
                fields=["user_modified", "user_created"],
                name="edc_qol_sf1_user_mo_070977_idx",
            ),
        ),
    ]



from django.contrib import admin
from edc_model_admin.dashboard import ModelAdminSubjectDashboardMixin
from edc_model_admin.history import SimpleHistoryAdmin

from ..admin_site import edc_qol_admin
from ..forms import IcecapaForm
from ..modeladmin_mixins import IcecapaModelAdminMixin
from ..models import Icecapa


@admin.register(Icecapa, site=edc_qol_admin)
class IcecapaAdmin(
    IcecapaModelAdminMixin, ModelAdminSubjectDashboardMixin, SimpleHistoryAdmin
):
    form = IcecapaForm



# Generated by Django 3.2.9 on 2021-11-15 17:06

import _socket
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django_audit_fields.models.audit_model_mixin
import django_revision.revision_field
import edc_sites.models
import edc_utils.date
import simple_history.models
import uuid


class Migration(migrations.Migration):
    dependencies = [
        ("sites", "0002_alter_domain_unique"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("edc_qol", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="Sf12",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("subject_identifier", models.CharField(max_length=50, unique=True)),
                (
                    "general_health",
                    models.CharField(
                        choices=[
                            ("excellent", "Excellent"),
                            ("very_good", "Very good"),
                            ("good", "Good"),
                            ("fair", "Fair"),
                            ("poor", "Poor"),
                        ],
                        max_length=15,
                        verbose_name="In general, would you say your health is:",
                    ),
                ),
                (
                    "moderate_activities_now_limited",
                    models.CharField(
                        choices=[
                            ("limited_a_lot", "YES, limited a lot"),
                            ("limited_a_little", "YES, limited a little"),
                            ("not_limited_at_all", "NO, not at all limited"),
                        ],
                        max_length=20,
                        verbose_name="<u>Moderate activities</u> such as moving a table, pushing a vacuum cleaner, bowling, or playing golf:",
                    ),
                ),
                (
                    "climbing_stairs_now_limited",
                    models.CharField(
                        choices=[
                            ("limited_a_lot", "YES, limited a lot"),
                            ("limited_a_little", "YES, limited a little"),
                            ("not_limited_at_all", "NO, not at all limited"),
                        ],
                        max_length=20,
                        verbose_name="Climbing <u>several</u> flights of stairs:",
                    ),
                ),
                (
                    "accomplished_less_physical_health",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="<u>Accomplished less</u> than you would like:",
                    ),
                ),
                (
                    "work_limited_physical_health",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Were limited in the <u>kind</u> of work or other activities:",
                    ),
                ),
                (
                    "accomplished_less_emotional",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="<u>Accomplished less</u> than you would like:",
                    ),
                ),
                (
                    "work_less_carefully_emotional",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Did work or activities <u>less carefully than usual</u>:",
                    ),
                ),
                (
                    "pain_interfere_work",
                    models.CharField(
                        choices=[
                            ("not_at_all", "Not at all"),
                            ("a_little_bit", "A little bit"),
                            ("moderately", "Moderately"),
                            ("quite_a-bit", "Quite a bit"),
                            ("extremely", "Extremely"),
                        ],
                        max_length=15,
                        verbose_name="During the <u>past 4 weeks</u>, how much <u>did pain interfere</u> with your normal work (including work outside the home and housework)?",
                    ),
                ),
                (
                    "felt_calm_peaceful",
                    models.CharField(
                        choices=[
                            ("all_of_the_time", "All of the time"),
                            ("most_of_the_time", "Most of the time"),
                            ("good_bit_of_the_time", " A good bit of the time"),
                            ("some_of_the_time", "Some of the time"),
                            ("little_of_the_time", "A little of the time"),
                            ("none_of_the_time", "None of the time"),
                        ],
                        max_length=25,
                        verbose_name="Have you felt calm & peaceful?",
                    ),
                ),
                (
                    "felt_lot_energy",
                    models.CharField(
                        choices=[
                            ("all_of_the_time", "All of the time"),
                            ("most_of_the_time", "Most of the time"),
                            ("good_bit_of_the_time", " A good bit of the time"),
                            ("some_of_the_time", "Some of the time"),
                            ("little_of_the_time", "A little of the time"),
                            ("none_of_the_time", "None of the time"),
                        ],
                        max_length=25,
                        verbose_name="Did you have a lot of energy?",
                    ),
                ),
                (
                    "felt_down",
                    models.CharField(
                        choices=[
                            ("all_of_the_time", "All of the time"),
                            ("most_of_the_time", "Most of the time"),
                            ("good_bit_of_the_time", " A good bit of the time"),
                            ("some_of_the_time", "Some of the time"),
                            ("little_of_the_time", "A little of the time"),
                            ("none_of_the_time", "None of the time"),
                        ],
                        max_length=25,
                        verbose_name="Have you felt down-hearted and blue?",
                    ),
                ),
                (
                    "social_activities_interfered",
                    models.CharField(
                        choices=[
                            ("all_of_the_time", "All of the time"),
                            ("most_of_the_time", "Most of the time"),
                            ("some_of_the_time", "Some of the time"),
                            ("little_of_the_time", "A little of the time"),
                            ("none_of_the_time", "None of the time"),
                        ],
                        max_length=25,
                        verbose_name="During the <u>past 4 weeks</u>, how much of the time has your physical health or emotional problems interfered with your social activities (like visiting friends, relatives, etc.)?",
                    ),
                ),
                ("report_datetime", models.DateTimeField(default=edc_utils.date.get_utcnow)),
                (
                    "site",
                    models.ForeignKey(
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
            ],
            options={
                "verbose_name": "SF-12 Health Survey",
                "verbose_name_plural": "SF-12 Health Survey",
                "ordering": ("-modified", "-created"),
                "get_latest_by": "modified",
                "abstract": False,
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
            },
            managers=[
                ("on_site", edc_sites.models.CurrentSiteManager()),
            ],
        ),
        migrations.CreateModel(
            name="HistoricalSf12",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        db_index=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                    ),
                ),
                ("subject_identifier", models.CharField(db_index=True, max_length=50)),
                (
                    "general_health",
                    models.CharField(
                        choices=[
                            ("excellent", "Excellent"),
                            ("very_good", "Very good"),
                            ("good", "Good"),
                            ("fair", "Fair"),
                            ("poor", "Poor"),
                        ],
                        max_length=15,
                        verbose_name="In general, would you say your health is:",
                    ),
                ),
                (
                    "moderate_activities_now_limited",
                    models.CharField(
                        choices=[
                            ("limited_a_lot", "YES, limited a lot"),
                            ("limited_a_little", "YES, limited a little"),
                            ("not_limited_at_all", "NO, not at all limited"),
                        ],
                        max_length=20,
                        verbose_name="<u>Moderate activities</u> such as moving a table, pushing a vacuum cleaner, bowling, or playing golf:",
                    ),
                ),
                (
                    "climbing_stairs_now_limited",
                    models.CharField(
                        choices=[
                            ("limited_a_lot", "YES, limited a lot"),
                            ("limited_a_little", "YES, limited a little"),
                            ("not_limited_at_all", "NO, not at all limited"),
                        ],
                        max_length=20,
                        verbose_name="Climbing <u>several</u> flights of stairs:",
                    ),
                ),
                (
                    "accomplished_less_physical_health",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="<u>Accomplished less</u> than you would like:",
                    ),
                ),
                (
                    "work_limited_physical_health",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Were limited in the <u>kind</u> of work or other activities:",
                    ),
                ),
                (
                    "accomplished_less_emotional",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="<u>Accomplished less</u> than you would like:",
                    ),
                ),
                (
                    "work_less_carefully_emotional",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Did work or activities <u>less carefully than usual</u>:",
                    ),
                ),
                (
                    "pain_interfere_work",
                    models.CharField(
                        choices=[
                            ("not_at_all", "Not at all"),
                            ("a_little_bit", "A little bit"),
                            ("moderately", "Moderately"),
                            ("quite_a-bit", "Quite a bit"),
                            ("extremely", "Extremely"),
                        ],
                        max_length=15,
                        verbose_name="During the <u>past 4 weeks</u>, how much <u>did pain interfere</u> with your normal work (including work outside the home and housework)?",
                    ),
                ),
                (
                    "felt_calm_peaceful",
                    models.CharField(
                        choices=[
                            ("all_of_the_time", "All of the time"),
                            ("most_of_the_time", "Most of the time"),
                            ("good_bit_of_the_time", " A good bit of the time"),
                            ("some_of_the_time", "Some of the time"),
                            ("little_of_the_time", "A little of the time"),
                            ("none_of_the_time", "None of the time"),
                        ],
                        max_length=25,
                        verbose_name="Have you felt calm & peaceful?",
                    ),
                ),
                (
                    "felt_lot_energy",
                    models.CharField(
                        choices=[
                            ("all_of_the_time", "All of the time"),
                            ("most_of_the_time", "Most of the time"),
                            ("good_bit_of_the_time", " A good bit of the time"),
                            ("some_of_the_time", "Some of the time"),
                            ("little_of_the_time", "A little of the time"),
                            ("none_of_the_time", "None of the time"),
                        ],
                        max_length=25,
                        verbose_name="Did you have a lot of energy?",
                    ),
                ),
                (
                    "felt_down",
                    models.CharField(
                        choices=[
                            ("all_of_the_time", "All of the time"),
                            ("most_of_the_time", "Most of the time"),
                            ("good_bit_of_the_time", " A good bit of the time"),
                            ("some_of_the_time", "Some of the time"),
                            ("little_of_the_time", "A little of the time"),
                            ("none_of_the_time", "None of the time"),
                        ],
                        max_length=25,
                        verbose_name="Have you felt down-hearted and blue?",
                    ),
                ),
                (
                    "social_activities_interfered",
                    models.CharField(
                        choices=[
                            ("all_of_the_time", "All of the time"),
                            ("most_of_the_time", "Most of the time"),
                            ("some_of_the_time", "Some of the time"),
                            ("little_of_the_time", "A little of the time"),
                            ("none_of_the_time", "None of the time"),
                        ],
                        max_length=25,
                        verbose_name="During the <u>past 4 weeks</u>, how much of the time has your physical health or emotional problems interfered with your social activities (like visiting friends, relatives, etc.)?",
                    ),
                ),
                ("report_datetime", models.DateTimeField(default=edc_utils.date.get_utcnow)),
                (
                    "history_id",
                    models.UUIDField(
                        default=uuid.uuid4, editable=False, primary_key=True, serialize=False
                    ),
                ),
                ("history_date", models.DateTimeField()),
                ("history_change_reason", models.CharField(max_length=100, null=True)),
                (
                    "history_type",
                    models.CharField(
                        choices=[("+", "Created"), ("~", "Changed"), ("-", "Deleted")],
                        max_length=1,
                    ),
                ),
                (
                    "history_user",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
            ],
            options={
                "verbose_name": "historical SF-12 Health Survey",
                "ordering": ("-history_date", "-history_id"),
                "get_latest_by": "history_date",
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
    ]



# Generated by Django 4.2.1 on 2023-07-07 19:32

import django.db.models.manager
import edc_sites.models
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("edc_qol", "0006_alter_eq5d3l_options_alter_icecapa_options_and_more"),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="eq5d3l",
            managers=[
                ("objects", django.db.models.manager.Manager()),
                ("on_site", edc_sites.models.CurrentSiteManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="icecapa",
            managers=[
                ("objects", django.db.models.manager.Manager()),
                ("on_site", edc_sites.models.CurrentSiteManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="sf12",
            managers=[
                ("objects", django.db.models.manager.Manager()),
                ("on_site", edc_sites.models.CurrentSiteManager()),
            ],
        ),
    ]



from django import forms
from edc_crf.crf_form_validator import CrfFormValidator
from edc_crf.modelform_mixins import CrfModelFormMixin

from ..models import Sf12


class Sf12FormValidator(CrfFormValidator):
    pass


class Sf12Form(CrfModelFormMixin, forms.ModelForm):
    form_validator_cls = Sf12FormValidator

    class Meta:
        model = Sf12
        fields = "__all__"



# Generated by Django 4.2.4 on 2023-08-23 15:52

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_qol", "0008_alter_eq5d3l_device_created_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalsf12",
            name="felt_calm_peaceful",
            field=models.CharField(
                choices=[
                    ("all_of_the_time", "All of the time"),
                    ("most_of_the_time", "Most of the time"),
                    ("good_bit_of_the_time", "A good bit of the time"),
                    ("some_of_the_time", "Some of the time"),
                    ("little_of_the_time", "A little of the time"),
                    ("none_of_the_time", "None of the time"),
                ],
                max_length=25,
                verbose_name="Have you felt calm & peaceful?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsf12",
            name="felt_down",
            field=models.CharField(
                choices=[
                    ("all_of_the_time", "All of the time"),
                    ("most_of_the_time", "Most of the time"),
                    ("good_bit_of_the_time", "A good bit of the time"),
                    ("some_of_the_time", "Some of the time"),
                    ("little_of_the_time", "A little of the time"),
                    ("none_of_the_time", "None of the time"),
                ],
                max_length=25,
                verbose_name="Have you felt down-hearted and blue?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsf12",
            name="felt_lot_energy",
            field=models.CharField(
                choices=[
                    ("all_of_the_time", "All of the time"),
                    ("most_of_the_time", "Most of the time"),
                    ("good_bit_of_the_time", "A good bit of the time"),
                    ("some_of_the_time", "Some of the time"),
                    ("little_of_the_time", "A little of the time"),
                    ("none_of_the_time", "None of the time"),
                ],
                max_length=25,
                verbose_name="Did you have a lot of energy?",
            ),
        ),
        migrations.AlterField(
            model_name="sf12",
            name="felt_calm_peaceful",
            field=models.CharField(
                choices=[
                    ("all_of_the_time", "All of the time"),
                    ("most_of_the_time", "Most of the time"),
                    ("good_bit_of_the_time", "A good bit of the time"),
                    ("some_of_the_time", "Some of the time"),
                    ("little_of_the_time", "A little of the time"),
                    ("none_of_the_time", "None of the time"),
                ],
                max_length=25,
                verbose_name="Have you felt calm & peaceful?",
            ),
        ),
        migrations.AlterField(
            model_name="sf12",
            name="felt_down",
            field=models.CharField(
                choices=[
                    ("all_of_the_time", "All of the time"),
                    ("most_of_the_time", "Most of the time"),
                    ("good_bit_of_the_time", "A good bit of the time"),
                    ("some_of_the_time", "Some of the time"),
                    ("little_of_the_time", "A little of the time"),
                    ("none_of_the_time", "None of the time"),
                ],
                max_length=25,
                verbose_name="Have you felt down-hearted and blue?",
            ),
        ),
        migrations.AlterField(
            model_name="sf12",
            name="felt_lot_energy",
            field=models.CharField(
                choices=[
                    ("all_of_the_time", "All of the time"),
                    ("most_of_the_time", "Most of the time"),
                    ("good_bit_of_the_time", "A good bit of the time"),
                    ("some_of_the_time", "Some of the time"),
                    ("little_of_the_time", "A little of the time"),
                    ("none_of_the_time", "None of the time"),
                ],
                max_length=25,
                verbose_name="Did you have a lot of energy?",
            ),
        ),
    ]



from django.utils.functional import lazy
from django.utils.html import format_html
from django.utils.translation import gettext_lazy as _

from .constants import (
    ALL_OF_THE_TIME,
    CONFINED_TO_BED,
    EXTREME_ANXIOUS_DEPRESSED,
    EXTREME_PAIN_DISCOMFORT,
    GOOD_BIT_OF_THE_TIME,
    LITTLE_OF_THE_TIME,
    MODERATE_ANXIOUS_DEPRESSED,
    MODERATE_PAIN_DISCOMFORT,
    MOST_OF_THE_TIME,
    NO_PAIN_DISCOMFORT,
    NO_PROBLEM_SELF_CARE,
    NO_PROBLEM_USUAL_ACTIVITIES,
    NO_PROBLEM_WALKING,
    NONE_OF_THE_TIME,
    NOT_ANXIOUS_DEPRESSED,
    PROBLEM_WASHING_DRESSING,
    SOME_OF_THE_TIME,
    SOME_PROBLEM_USUAL_ACTIVITIES,
    SOME_PROBLEM_WALKING,
    UNABLE_PERFORM_USUAL_ACTIVITIES,
    UNABLE_WASH_DRESS,
)

format_html_lazy = lazy(format_html, str)
DESCRIBE_HEALTH_CHOICES = (
    ("excellent", _("Excellent")),
    ("very_good", _("Very good")),
    ("good", _("Good")),
    ("fair", _("Fair")),
    ("poor", _("Poor")),
)

FEELING_DURATION_CHOICES = (
    (ALL_OF_THE_TIME, _("All of the time")),
    (MOST_OF_THE_TIME, _("Most of the time")),
    (GOOD_BIT_OF_THE_TIME, _("A good bit of the time")),
    (SOME_OF_THE_TIME, _("Some of the time")),
    (LITTLE_OF_THE_TIME, _("A little of the time")),
    (NONE_OF_THE_TIME, _("None of the time")),
)

HEALTH_LIMITED_CHOICES = (
    ("limited_a_lot", _("YES, limited a lot")),
    ("limited_a_little", _("YES, limited a little")),
    ("not_limited_at_all", _("NO, not at all limited")),
)

INTERFERENCE_DURATION_CHOICES = (
    (ALL_OF_THE_TIME, _("All of the time")),
    (MOST_OF_THE_TIME, _("Most of the time")),
    (SOME_OF_THE_TIME, _("Some of the time")),
    (LITTLE_OF_THE_TIME, _("A little of the time")),
    (NONE_OF_THE_TIME, _("None of the time")),
)

MOBILITY = (
    (NO_PROBLEM_WALKING, _("I have no problems in walking about")),
    (SOME_PROBLEM_WALKING, _("I have some problems in walking about")),
    (CONFINED_TO_BED, _("I am confined to bed")),
)

SELF_CARE = (
    (NO_PROBLEM_SELF_CARE, _("I have no problems with self-care")),
    (PROBLEM_WASHING_DRESSING, _("I have some problems washing or dressing myself")),
    (UNABLE_WASH_DRESS, _("I am unable to wash or dress myself")),
)

USUAL_ACTIVITIES = (
    (NO_PROBLEM_USUAL_ACTIVITIES, _("I have no problems with performing my usual activities")),
    (
        SOME_PROBLEM_USUAL_ACTIVITIES,
        _("I have some problems with performing my usual activities"),
    ),
    (UNABLE_PERFORM_USUAL_ACTIVITIES, _("I am unable to perform my usual activities")),
)

PAIN_DISCOMFORT = (
    (NO_PAIN_DISCOMFORT, _("I have no pain or discomfort")),
    (MODERATE_PAIN_DISCOMFORT, _("I have moderate pain or discomfort")),
    (EXTREME_PAIN_DISCOMFORT, _("I have extreme pain or discomfort")),
)

ANXIETY_DEPRESSION = (
    (NOT_ANXIOUS_DEPRESSED, _("I am not anxious or depressed")),
    (MODERATE_ANXIOUS_DEPRESSED, _("I am moderately anxious or depressed")),
    (EXTREME_ANXIOUS_DEPRESSED, _("I am extremely anxious or depressed")),
)

WORK_PAIN_INTERFERENCE_CHOICES = (
    ("not_at_all", _("Not at all")),
    ("a_little_bit", _("A little bit")),
    ("moderately", _("Moderately")),
    ("quite_a-bit", _("Quite a bit")),
    ("extremely", _("Extremely")),
)

ICECAP_STABILITY = (
    (
        "4",
        format_html_lazy(
            _("I am able to feel settled and secure in <B>all</B> areas of my life")
        ),
    ),
    (
        "3",
        format_html_lazy(
            _("I am able to feel settled and secure in <B>many</B> areas of my life")
        ),
    ),
    (
        "2",
        format_html_lazy(
            _("I am able to feel settled and secure in a <B>few</B> areas of my life")
        ),
    ),
    (
        "1",
        format_html_lazy(
            _("I am <B>unable</B> to feel settled and secure in <B>any</B> areas of my life")
        ),
    ),
)


ICECAP_ATTACHMENT = (
    ("4", format_html_lazy(_("I can have <B>a lot</B> of love, friendship and support"))),
    (
        "3",
        format_html_lazy(_("I can have <B>quite a lot</B> of love, friendship and support")),
    ),
    ("2", format_html_lazy(_("I can have <B>a little</B> love, friendship and support"))),
    ("1", format_html_lazy(_("I <B>cannot</B> have <B>any</B> love, friendship and support"))),
)


ICECAP_AUTONOMY = (
    ("4", format_html_lazy(_("I am able to be <B>completely</B> independent"))),
    ("3", format_html_lazy(_("I am able to be independent in <B>many</B> things"))),
    ("2", format_html_lazy(_("I am able to be independent in <B>a few</B> things"))),
    ("1", format_html_lazy(_("I am <B>unable</B> to be at all independent"))),
)

ICECAP_ACHIEVMENT = (
    ("4", format_html_lazy(_("I can achieve and progress in <B>all</B> aspects of my life"))),
    ("3", format_html_lazy(_("I can achieve and progress in <B>many</B> aspects of my life"))),
    (
        "2",
        format_html_lazy(_("I can achieve and progress in <B>a few</B> aspects of my life")),
    ),
    (
        "1",
        format_html_lazy(
            _("I <B>cannot</B> achieve and progress in <B>any</B> aspects of my life")
        ),
    ),
)


ICECAP_ENJOYMENT = (
    ("4", format_html_lazy(_("I can have <B>a lot</B> of enjoyment and pleasure"))),
    ("3", format_html_lazy(_("I can have <B>quite a lot</B> of enjoyment and pleasure"))),
    ("2", format_html_lazy(_("I can have <B>a little</B> enjoyment and pleasure"))),
    ("1", format_html_lazy(_("I <B>cannot</B> have <B>any</B> enjoyment and pleasure"))),
)



from django.contrib import admin
from django.utils.translation import gettext_lazy as _
from django_audit_fields import audit_fieldset_tuple


def icecapa_fieldsets():
    return [
        (
            _("About your overall quality of life"),
            {
                "description": _(
                    "Please indicate which statements best describe your overall quality "
                    "of life at the moment by selecting ONE option for each of the five "
                    "questions below."
                ),
                "fields": ("stability", "attachment", "autonomy", "achievement", "enjoyment"),
            },
        ),
    ]


def icecapa_radio_fields():
    return {
        "stability": admin.VERTICAL,
        "attachment": admin.VERTICAL,
        "autonomy": admin.VERTICAL,
        "achievement": admin.VERTICAL,
        "enjoyment": admin.VERTICAL,
    }


class IcecapaModelAdminMixin:
    form = None

    fieldsets = (
        (None, {"fields": ("subject_identifier", "report_datetime")}),
        *icecapa_fieldsets(),
        audit_fieldset_tuple,
    )

    radio_fields = icecapa_radio_fields()



from django.db import models
from edc_identifier.model_mixins import UniqueSubjectIdentifierFieldMixin
from edc_model import models as edc_models
from edc_model.models import HistoricalRecords
from edc_sites.managers import CurrentSiteManager
from edc_sites.model_mixins import SiteModelMixin
from edc_utils import get_utcnow

from ..model_mixins import Sf12ModelMixin


class Sf12(
    UniqueSubjectIdentifierFieldMixin,
    Sf12ModelMixin,
    SiteModelMixin,
    edc_models.BaseUuidModel,
):
    report_datetime = models.DateTimeField(default=get_utcnow)

    objects = models.Manager()
    on_site = CurrentSiteManager()
    history = HistoricalRecords()

    class Meta(Sf12ModelMixin.Meta, edc_models.BaseUuidModel.Meta):
        pass
